@@ -1,9 +1,9 @@
 package Crypt::Passphrase::Linux;
-$Crypt::Passphrase::Linux::VERSION = '0.002';
+$Crypt::Passphrase::Linux::VERSION = '0.003';
 use strict;
 use warnings;
 
-use Crypt::Passphrase -encoder;
+use Crypt::Passphrase 0.010 -encoder;
 
 use Carp 'croak';
 use Crypt::Passwd::XS 'crypt';
@@ -85,7 +85,7 @@ Crypt::Passphrase::Linux - An linux crypt encoder for Crypt::Passphrase
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
